#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IDIVROUND_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IDIVROUND_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/idivround.hpp>

#endif
